package Win32::Perms;

#//////////////////////////////////////////////////////////////////////////////
#//
#//  Perms.pm
#//  Win32::Perms Perl package file
#//
#//  Copyright (c) 1998-2002 Dave Roth
#//  Courtesy of Roth Consulting
#//  http://www.roth.net/
#//
#//  This file may be copied or modified only under the terms of either 
#//  the Artistic License or the GNU General Public License, which may 
#//  be found in the Perl 5.0 source kit.
#//
#//  2002.06.05
#//
#//////////////////////////////////////////////////////////////////////////////

use vars qw( $VERSION $PACKAGE );
require Exporter;
require DynaLoader;

$PACKAGE = "Win32::Perms";
$VERSION = 20020605;


@ISA= qw( Exporter DynaLoader );
    # Items to export into callers namespace by default. Note: do not export
    # names by default without a very good reason. Use EXPORT_OK instead.
    # Do not simply export all your public functions/methods/constants.
@EXPORT = qw(
    ALL
    ALLOW
    ACCESS_ALLOWED_ACE_TYPE
    ACCESS_DENIED_ACE_TYPE
    ACCESS_SYSTEM_SECURITY
    ACCESS_ALLOWED_COMPOUND_ACE_TYPE        
    ACCESS_ALLOWED_OBJECT_ACE_TYPE          
    ACCESS_DENIED_OBJECT_ACE_TYPE           
    SYSTEM_AUDIT_OBJECT_ACE_TYPE            
    SYSTEM_ALARM_OBJECT_ACE_TYPE            
    ACCESS_ALLOWED_CALLBACK_ACE_TYPE        
    ACCESS_DENIED_CALLBACK_ACE_TYPE         
    ACCESS_ALLOWED_CALLBACK_OBJECT_ACE_TYPE 
    ACCESS_DENIED_CALLBACK_OBJECT_ACE_TYPE  
    SYSTEM_AUDIT_CALLBACK_ACE_TYPE          
    SYSTEM_ALARM_CALLBACK_ACE_TYPE          
    SYSTEM_AUDIT_CALLBACK_OBJECT_ACE_TYPE   
    SYSTEM_ALARM_CALLBACK_OBJECT_ACE_TYPE   
    AUDIT
    AUDIT_FAILURE
    AUDIT_SUCCESS
    CONTAINER
    CONTAINER_INHERIT_ACE
    CHANGE
    CHANGE_PERMISSION
    DELETE
    DENY
    DENY_ACCESS
    DIR
    DIRECTORY
    EXECUTE
    FAILED_ACCESS_ACE_FLAG
    FAILURE
    FILE
    FILE_APPEND_DATA
    FILE_DELETE_CHILD
    FILE_EXECUTE
    FILE_READ_ATTRIBUTES
    FILE_READ_DATA
    FILE_READ_EA
    FILE_WRITE_ATTRIBUTES
    FILE_WRITE_DATA
    FILE_WRITE_EA
    FULL
    GRANT_ACCESS
    GENERIC_ALL
    GENERIC_EXECUTE
    GENERIC_READ
    GENERIC_WRITE
    GRANT
    GRANT_ACCESS
    GROUP
    GROUP_ACE_TYPE
    INHERIT
    INHERIT_ONLY_ACE
    KEY
    MAXIMUM_ALLOWED
    NO_ACCESS
    NO_PROPAGATE_INHERIT_ACE
    NON_CONTAINER
    OBJECT_INHERIT_ACE
    OWNER
    OWNER_ACE_TYPE
	INHERITED_ACE

	PERM_TYPE_NULL
	PERM_TYPE_NONE
	PERM_TYPE_UNKNOWN
	PERM_TYPE_FILE
	PERM_TYPE_REGISTRY
	PERM_TYPE_SHARE
	PERM_TYPE_PRINTER
	PERM_TYPE_SERVICE
	PERM_TYPE_KERNEL
	PERM_TYPE_PRIVATE
	PERM_TYPE_SD
	PERM_TYPE_DIRECTORY

    READ
    READ_CONTROL
    SD_ABSOLUTE
    SD_RELATIVE
    ACL_ABSOLUTE
    ACL_RELATIVE
    SPECIFIC_RIGHTS_ALL
    STANDARD_RIGHTS_ALL
    STANDARD_RIGHTS_EXECUTE
    STANDARD_RIGHTS_READ
    STANDARD_RIGHTS_REQUIRED
    STANDARD_RIGHTS_WRITE
    SUCCESS
    SUCCESSFUL_ACCESS_ACE_FLAG
    SYNCHRONIZE
    SYSTEM_ALARM_ACE_TYPE
    SYSTEM_AUDIT_ACE_TYPE
    TAKE_OWNERSHIP
    VALUE
    WRITE
    WRITE_DAC
    WRITE_OWNER

    PRINTER_ALL_ACCESS
    PRINTER_READ
    PRINTER_WRITE
    PRINTER_EXECUTE
    JOB_ALL_ACCESS
    JOB_READ
    JOB_WRITE
    JOB_EXECUTE
    PRINT
    MANAGE_PRINTER_DOCUMENTS
    FULL_PRINTER_CONTROL
    FULL_PRINTER

    FULL_SHARE
    FULL_SHARE_CONTROL
    CHANGE_SHARE	
    READ_SHARE
    FILE_SHARE_READ
    FILE_SHARE_WRITE
    FILE_SHARE_DELETE

    READ_FILE
    CHANGE_FILE
    FULL_CONTROL_FILE

    READ_DATA_FILE
    WRITE_DATA_FILE
    APPEND_DATA_FILE
    READ_EATTRIB_FILE
    WRITE_EATTRIB_FILE
    EXECUTE_FILE
    READ_ATTRIB_FILE
    WRITE_ATTRIB_FILE
    ALL_ACCESS_FILE

    LIST_DIR
    ADD_DIR
    CHANGE_DIR
    FULL_CONTROL_DIR
    READ_DIR  
    ADD_FILE_DIR
    ADD_SUBDIR_DIR
    READ_EATTRIB_DIR
    WRITE_EATTRIB_DIR
    EXECUTE_DIR
    TRAVERSE_DIR
    DEL_SUB_DIR
    READ_ATTRIB_DIR
    WRITE_ATTRIB_DIR
    ALL_ACCESS_DIR
    DIR_READ
    DIR_ADD_FILE
    DIR_ADD_SUBDIR
    DIR_READ_EATTRIB
    DIR_WRITE_EATTRIB
    DIR_EXECUTE
    DIR_TRAVERSE
    DIR_DEL_SUBDIR
    DIR_READ_ATTRIB
    DIR_WRITE_ATTRIB
    DIR_ALL_ACCESS

	DecodeMask
	DecodeType
	DecodeFlag
);

@EXPORT_OK = qw(
);	

sub new
{
    my( $type, @Options ) = @_;
    my $self = bless {};

    $Result = Win32::Perms::New( $self, @Options );
    if( ! $Result )
    {
		undef %self;
        return undef;
    }
    return( $self );
}

bootstrap $PACKAGE;

sub AUTOLOAD 
{
    # This AUTOLOAD is used to 'autoload' constants from the constant()
    # XS function.  If a constant is not found then control is passed
    # to the AUTOLOAD in AutoLoader.

    my( $Constant ) = $AUTOLOAD;
    my( $Result, $Value );
    $Constant =~ s/.*:://;

    $Result = Constant( $Constant, $Value );

    if( 0 == $Result )
    {
        # The extension could not resolve the constant...
        $AutoLoader::AUTOLOAD = $AUTOLOAD;
	    goto &AutoLoader::AUTOLOAD;
        return;
    }
    elsif( 1 == $Result )
    {
        # $Result == 1 if the constant is valid but not defined
        # that is, the extension knows that the constant exists but for
        # some wild reason it was not compiled with it.
        $pack = 0; 
        ($pack,$file,$line) = caller;
        print "Your vendor has not defined $PACKAGE macro $constname, used in $file at line $line.";
    }
    elsif( 2 == $Result )
    {
        # If $Result == 2 then we have a string value
        $Value = "'$Value'";
    }
        # If $Result == 3 then we have a numeric value

    eval "sub $AUTOLOAD { return( $Value ); }";
    goto &$AUTOLOAD;
}

1;

__END__



